"""The init file of the package."""

__version__ = "0.0.0"
__author__ = "Pierrick Rambaud"
__email__ = "pierrick.rambaud49@gmail.com"


def hello_world() -> str:
    """Hello world demo method.

    Returns:
        the hello world string
    """
    return "hello world !"
